function [L, p] = merge_sorted_ascending(L1, L2)
%
%   [L,p] = = merge_sorted_ascending(L1, L2)
%
%   Inputs: 
%       L1,L2 = arrays of real numbers, sorted from left to right.
%
%   Outputs:
%       L = the combined sorted list 
%       p = a sort index that specifies how the elements of the combined
%       list L = [L1(:); L2(:)] were rearranged
%
%   Merges two sorted ascending arrays L1 and L2 using a single step of
%   merge sort. 
%
%   WARNING: There is no error checking or argument validation. Things will
%   go horribly wrong if the two input lists are not already sorted.
%
%   10 DECEMBER 2023 by Carlos F. Borges

% Combine the input arrays.
L = [L1(:); L2(:)];
m = length(L1);
n = length(L);
p1 = 1:m;
p = 1:n;

% Combine the arrays.
L = [L1; L2];
% A single step of merge sort puts it all in order.
i = 1;
j = m + 1;
k = 1;
while ((k < j) && (j <= n))
    if (L1(i) <= L(j))
        L(k) = L1(i);
        p(k) = p1(i);
        i = i + 1;
    else
        L(k) = L(j);
        p(k) = p(j);
        j = j + 1;
    end
    k = k + 1;
end
L(k:(j - 1)) = L1(i:(i + j - k - 1));
p(k:(j - 1)) = p1(i:(i + j - k - 1));
% End merge
end